%define distname %{name}-%{version}

# See:
# https://bugs.freedesktop.org/show_bug.cgi?id=91643
%bcond_with egl

Name:		mesa-demos
Version: 	8.4.0
Release: 	%mkrel 4
Summary:	Demos for Mesa (OpenGL compatible 3D lib)
Group:		Graphics/Utilities

# (tv) BR probably need to be shrinked:
BuildRequires:	tcl
BuildRequires:	texinfo
BuildRequires:	pkgconfig(xfixes)		>= 4.0.3
BuildRequires:	pkgconfig(xt)		>= 1.0.5
BuildRequires:	pkgconfig(xmu)		>= 1.0.3
BuildRequires:	pkgconfig(x11)		>= 1.3.3
BuildRequires:	pkgconfig(xdamage)	>= 1.1.1
BuildRequires:	pkgconfig(expat)		>= 2.0.1
BuildRequires:	gccmakedep
BuildRequires:	x11-proto-devel		>= 7.3
BuildRequires:	pkgconfig(libdrm)		>= 2.4.19-3

BuildRequires:	pkgconfig(xext)		>= 1.1.1
BuildRequires:	pkgconfig(xxf86vm)	>= 1.1.0
BuildRequires:	pkgconfig(xi)		>= 1.3

BuildRequires:	pkgconfig(glew)

%if %with egl
BuildRequires:	mesaegl-devel
BuildRequires:	mesaglesv1-devel
BuildRequires:	mesaglesv2-devel
%endif
BuildRequires:	gbm-devel

# (tv) for glinfo:
BuildRequires:	pkgconfig(freeglut)

URL:		http://www.mesa3d.org
# git clone git://anongit.freedesktop.org/mesa/demos
# NAME=mesa-demos; DATE=$(git show -s --pretty=%ai | awk '{ gsub("-", "", $1); print $1 }'); DISTNAME=$NAME-$DATE ; git archive --format=tar.gz --prefix=$DISTNAME/ HEAD > $DISTNAME.tar.gz
Source0:	ftp://ftp.freedesktop.org/pub/mesa/demos/%{distname}.tar.bz2
Source4:	Mesa-icons.tar.bz2

License:	MIT

Requires:	glxinfo = %{version}

%package -n	glxinfo
Summary:	Commandline GLX information tool
Group:		Graphics/Utilities
Conflicts:	mesa-demos < 7.7-4

%description
Mesa is an OpenGL 2.1 compatible 3D graphics library.

This package contains some demo programs for the Mesa library.

%description -n	glxinfo
Mesa is an OpenGL 2.1 compatible 3D graphics library.

This package contains the glinfo & glxinfo GLX information utility.

%prep
%setup -q -n %{distname}
%autopatch -p1
perl -pi -e "s,\"([^/].+?)\.(vert|geom|frag)\",\"%{_datadir}/%{name}/\$1.\$2\",g" src/*/*.c

%build
LIB_DIR=%{_lib}
INCLUDE_DIR=%{buildroot}%{_includedir}
export LIB_DIR INCLUDE_DIR DRI_DRIVER_DIR

autoreconf -fvi
%configure --with-system-data-files \
%if %without egl
    --disable-egl \
%endif


%make_build

%install
%make_install

# (fg) So that demos at least work :)
cp -a src/*/*.{frag,vert,geom} %{buildroot}%{_datadir}/%{name}

# (tv) fix conflict with bitmap:
mv %{buildroot}%{_bindir}/bitmap{,-gl}

%if %with egl
# (blino) install some egl test apps as well
pushd src/egl/opengl
for p in eglgears_screen eglgears_x11 eglinfo eglkms egltri_screen egltri_x11 peglgears xeglgears xeglthreads; do
    install -m755 $p %{buildroot}%{_bindir}
done
popd
%endif

# icons for three demos examples [we lack a frontend
# to launch the demos obviously]
install -d %{buildroot}%{_miconsdir}
install -d %{buildroot}%{_iconsdir}
install -d %{buildroot}%{_liconsdir}
tar jxvf %{SOURCE4} -C %{buildroot}%{_iconsdir}

%files
%{_bindir}/*
%exclude %{_bindir}/glxinfo
%exclude %{_bindir}/glinfo
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/*
%{_miconsdir}/*demos*.png
%{_iconsdir}/*demos*.png
%{_liconsdir}/*demos*.png

%files -n glxinfo
%{_bindir}/glxinfo
%{_bindir}/glinfo


%changelog
* Wed Dec 02 2020 luigiwalser <luigiwalser> 8.4.0-4.mga8
+ Revision: 1651358
- rebuild for glew

* Thu Feb 13 2020 umeabot <umeabot> 8.4.0-3.mga8
+ Revision: 1515148
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Sep 23 2018 umeabot <umeabot> 8.4.0-2.mga7
+ Revision: 1299522
- Mageia 7 Mass Rebuild

* Fri Feb 23 2018 tv <tv> 8.4.0-1.mga7
+ Revision: 1204347
- new release
- new release

* Mon Dec 04 2017 daviddavid <daviddavid> 8.3.0-3.mga7
+ Revision: 1181165
- rebuild for new glew 2.1.0

* Thu Sep 29 2016 umeabot <umeabot> 8.3.0-2.mga7
+ Revision: 1057496
- Mageia 6 Mass Rebuild

* Thu Dec 10 2015 tv <tv> 8.3.0-1.mga6
+ Revision: 909341
- new release

* Thu Sep 10 2015 shlomif <shlomif> 8.2.0-7.mga6
+ Revision: 875386
- Made the handling of no-EGL better (so can be built outside the BS).

* Mon Aug 24 2015 sander85 <sander85> 8.2.0-6.mga6
+ Revision: 869129
- Rebuild for glew 1.13.0

* Fri Aug 14 2015 tv <tv> 8.2.0-5.mga6
+ Revision: 864684
- disable EGL thus fixing build
+ akien <akien>
- Rebuild for GLEW 1.12

* Wed Oct 15 2014 umeabot <umeabot> 8.2.0-4.mga5
+ Revision: 751132
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 8.2.0-3.mga5
+ Revision: 682363
- Mageia 5 Mass Rebuild

* Mon Sep 01 2014 luigiwalser <luigiwalser> 8.2.0-2.mga5
+ Revision: 670273
- rebuild for glew

* Sun Jul 06 2014 tv <tv> 8.2.0-1.mga5
+ Revision: 644071
- drop merged patch
- new release

* Sun Jun 22 2014 akien <akien> 8.1.0-4.mga5
+ Revision: 638635
- Add upstream patch to fix build with gcc 4.9

* Sat Oct 19 2013 umeabot <umeabot> 8.1.0-3.mga4
+ Revision: 530460
- Mageia 4 Mass Rebuild

* Wed Jul 24 2013 sander85 <sander85> 8.1.0-2.mga4
+ Revision: 457716
- Rebuild for new glew

* Sun Feb 24 2013 tmb <tmb> 8.1.0-1.mga3
+ Revision: 400229
- update to 8.1.0 (mga #9170)

* Thu Jan 24 2013 fwang <fwang> 8.0.1-8.20120910.2.mga3
+ Revision: 391847
- update rpm group

* Mon Sep 10 2012 blino <blino> 8.0.1-8.20120910.1.mga3
+ Revision: 292087
- install some egl test apps
- update to snapshot from 20120910
- drop merged patch

* Sun Aug 19 2012 pterjan <pterjan> 8.0.1-8.20120722.1.mga3
+ Revision: 282391
- Rebuild for new glew

* Tue Aug 07 2012 blino <blino> 8.0.1-7.20120722.1.mga3
+ Revision: 279898
- eglkms: adapt to gbm stride API change (reported as fdo #53226)
- update to snapshot from 20120722

* Mon Apr 23 2012 blino <blino> 8.0.1-7.20120227.2.mga2
+ Revision: 232785
- really use system data files and add back hacks to use/install .frag/.vert/.geom files

* Fri Mar 02 2012 blino <blino> 8.0.1-7.20120227.1.mga2
+ Revision: 216616
- use git snapshot (20120227)
- enable egl and gles demos
- remove manual data install, now done by autotools
- remove clear binary renaming, it does not exist anymore
- remove patch0 (literal string), merged upstream

* Mon Oct 03 2011 fwang <fwang> 8.0.1-7.mga2
+ Revision: 151182
- rebuild for new glew

* Thu Sep 22 2011 pterjan <pterjan> 8.0.1-6.mga2
+ Revision: 146834
- Swtich to freeglut (#2541)

* Mon Jan 17 2011 pterjan <pterjan> 8.0.1-5.mga1
+ Revision: 20972
- Drop old stuff
- imported package mesa-demos


* Thu Jan 06 2011 Paulo Ricardo Zanoni <pzanoni@mandriva.com> 8.0.1-5mdv2011.0
+ Revision: 629150
- Re-enable Werror_cflags and add patch to fix errors (submitted upstream)
- Remove disable_ld_no_undefined since it was not for the demos
- Don't define src_type since it's only used once
- Remove useless makedepend macro

* Wed Oct 06 2010 Thierry Vignaud <tv@mandriva.org> 8.0.1-4mdv2011.0
+ Revision: 583892
- fix conflict with bitmap (#61211)
- cleanup now that we have proper BR for glinfo & the like
- fix even more paths in demos and do it faster

* Wed Oct 06 2010 Thierry Vignaud <tv@mandriva.org> 8.0.1-3mdv2011.0
+ Revision: 583353
- fix more paths in demos and do it faster
  (but 8.0.1 still lacks some files)
- package more data files
- relax require on glxinfo
- parallel build is OK

* Wed Oct 06 2010 Thierry Vignaud <tv@mandriva.org> 8.0.1-2mdv2011.0
+ Revision: 583243
- package more data files for demos

* Wed Oct 06 2010 Thierry Vignaud <tv@mandriva.org> 8.0.1-1mdv2011.0
+ Revision: 583191
- BuildRequires mesaglut-devel for glinfo
- build fix
- import mesa-demos

